==> ejc-cost-api-3.0.0-20201216.080347-16-sources.jar: com/ejianc/business/cost/vo/BillSettingVO.java <==
package com.ejianc.business.cost.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 单据设置
 * 
 * @author generator
 * 
 */
public class BillSettingVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billTypeCode; // 单据类型编码
    private java.lang.String billType; // 单据类型名称
    private java.lang.String parameter; // 查询字段
    private java.lang.String conditions; // 查询条件
    private java.lang.String path; // 对应单据跳转路径
    private java.lang.String createUserName; // 创建人名称
    

    /**
     * 单据类型编码
     */
    public java.lang.String getBillTypeCode() {
        return billTypeCode;
    }

    /**
     * 单据类型编码
     */
    public void setBillTypeCode(java.lang.String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    /**
     * 单据类型名称
     */
    public java.lang.String getBillType() {
        return billType;
    }

    /**
     * 单据类型名称
     */
    public void setBillType(java.lang.String billType) {
        this.billType = billType;
    }
    /**
     * 查询字段
     */
    public java.lang.String getParameter() {
        return parameter;
    }

    /**
     * 查询字段
     */
    public void setParameter(java.lang.String parameter) {
        this.parameter = parameter;
    }
    /**
     * 查询条件
     */
    public String getConditions() {
        return conditions;
    }

    public void setConditions(String conditions) {
        this.conditions = conditions;
    }

    /**
     * 对应单据跳转路径
     */
    public java.lang.String getPath() {
        return path;
    }

    /**
     * 对应单据跳转路径
     */
    public void setPath(java.lang.String path) {
        this.path = path;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}

==> ejc-cost-api-3.0.0-20210306.102620-59-sources.jar: com/ejianc/business/cost/vo/BillSettingVO.java <==
package com.ejianc.business.cost.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 单据设置
 * 
 * @author generator
 * 
 */
public class BillSettingVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billTypeCode; // 单据类型编码
    private java.lang.String billType; // 单据类型名称
    private java.lang.String parameter; // 查询字段
    private java.lang.String conditions; // 查询条件
    private java.lang.String path; // 对应单据跳转路径
    private java.lang.String createUserName; // 创建人名称
    private java.lang.Integer type; // 物资类型  0-出库入成本，1-物资合同结算入成本，2-通用

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    /**
     * 单据类型编码
     */
    public java.lang.String getBillTypeCode() {
        return billTypeCode;
    }

    /**
     * 单据类型编码
     */
    public void setBillTypeCode(java.lang.String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    /**
     * 单据类型名称
     */
    public java.lang.String getBillType() {
        return billType;
    }

    /**
     * 单据类型名称
     */
    public void setBillType(java.lang.String billType) {
        this.billType = billType;
    }
    /**
     * 查询字段
     */
    public java.lang.String getParameter() {
        return parameter;
    }

    /**
     * 查询字段
     */
    public void setParameter(java.lang.String parameter) {
        this.parameter = parameter;
    }
    /**
     * 查询条件
     */
    public String getConditions() {
        return conditions;
    }

    public void setConditions(String conditions) {
        this.conditions = conditions;
    }

    /**
     * 对应单据跳转路径
     */
    public java.lang.String getPath() {
        return path;
    }

    /**
     * 对应单据跳转路径
     */
    public void setPath(java.lang.String path) {
        this.path = path;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}
